Repository for NZ allocation and usage Python tools
=============================================================

This git repository contains the NZ allocation and usage Python tools and associated documentation.

.. Documentation
.. --------------
.. The primary documentation for the package can be found `here <http://hilltop-py.readthedocs.io>`_.

Installation
------------
nz-allo-usage-tools can be installed via pip or conda::

  pip install nz-allo-usage-tools

or::

  conda install -c mullenkamp nz-allo-usage-tools

The main dependencies are `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_ and boto3.
